'use client'

import { Cookies, XVideosOrientations } from '@/meta/settings';

import css from './Orientation.module.scss'

import React from 'react';

import { setCookie } from '@/utils/cookies/write';
import { useCookies } from 'react-cookie';

interface Props {
    handleClose(): void
    labels: {
        title: string,
    }
}

const Orientation: React.FC<Props> = (props) => {

    const { labels, handleClose } = props
    
    const [cookies] = useCookies([Cookies.orientation]);

    const handleChange = async (event: React.ChangeEvent<HTMLSelectElement>) => {
        const value = event.target.value;

        await setCookie(Cookies.orientation, value)

        handleClose()
    }

    return (
        <div className={css.container}>
            <div className={css.title}>{labels.title}</div>
            <select defaultValue={ cookies.orientation ?? XVideosOrientations.etero } onChange={handleChange} name={'orientation'} aria-label={labels.title}>
                {Object.keys(XVideosOrientations).map((elem, key) => {
                    return <option className={css.option} key={key} value={elem}>{elem.toUpperCase()}</option>
                })}
            </select>
        </div>
    );
};

export default Orientation;