'use client'

import React from 'react';

import style from './Player.module.scss'

import VideoJS from './VideoJS';
import { VideoData } from '@/meta/data';

import 'videojs-hls-quality-selector';

interface Props {
  data: VideoData
}

const Player: React.FC<Props> = (props) => {

  const { data } = props;

  const videoSrc = data.hlsUrl ?? data.lowResUrl
  const videoType = data.hlsUrl ? 'application/x-mpegURL' : 'video/mp4'

  const playerRef = React.useRef(null);

  const videoJsOptions = {
    autoplay: true,
    controls: true,
    responsive: true,
    fluid: true,
    sources: [{
      src: videoSrc,
      type: videoType
    }]
  };

  //@ts-ignore
  const handlePlayerReady = (player) => {
    playerRef.current = player;

    player.hlsQualitySelector({
      vjsIconClass: "vjs-icon-hd"
    })

    // You can handle player events here, for example:
    player.on('waiting', () => {
      console.log('player is waiting');
    });

    player.on('dispose', () => {
      console.log('player will dispose');
    });

  };


  return (
    <div className={style.container}>
      <VideoJS options={videoJsOptions} onReady={handlePlayerReady} />
    </div>
  );
};

export default Player;