'use client'

import React from 'react';

import style from './SearchBarForm.module.scss'

import { useRouter } from 'next/navigation'

interface Props {
    query?: string
    locale: string
    labels: {
        query: { placeholder: string }
        submit: { value: string }
    }
}

const MAX_SEARCH_LENGTH = 50;

const SearchBarForm: React.FC<Props> = (props) => {

    const { query, labels, locale } = props;

    const router = useRouter()

    const handleSubmit = (event: React.FormEvent<HTMLFormElement>) => {
        event.preventDefault();
        
        //@ts-ignore
        const query = event.target.query.value

        if (query.length > 0) {
            router.push(`/${locale}/search/${query}`)
        }
    }

    return (
        <form onSubmit={handleSubmit} className={style.searchForm} method="get" action="/">
            <input className={style.query} type="text" size={MAX_SEARCH_LENGTH} name="query" placeholder={labels.query.placeholder} defaultValue={query ?? undefined} />
            <input className={style.submitBtn} type="submit" value={labels.submit.value} />
        </form>
    );
};

export default SearchBarForm;